"use strict";
exports.__esModule = true;
var html_1 = require("./html");
var BROWSER = typeof window !== "undefined";
var DEBUG = (function () {
    if (BROWSER) {
        return window.location.hostname === "localhost" || window.location.search.indexOf("autotune-debug") !== -1;
    }
    return false;
})();
var BrowserEnvironment = (function () {
    function BrowserEnvironment() {
    }
    BrowserEnvironment.prototype.log = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (DEBUG) {
            console.log.apply(console, ["AUTOTUNE"].concat(args));
        }
    };
    BrowserEnvironment.prototype.error = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        console.error.apply(console, ["AUTOTUNE"].concat(args));
    };
    BrowserEnvironment.prototype.getTimeZoneOffset = function () {
        return new Date().getTimezoneOffset();
    };
    BrowserEnvironment.prototype.getLocalLanguage = function () {
        try {
            var n = navigator;
            return n.language || n.userLanguage;
        }
        catch (_a) {
            return undefined;
        }
    };
    BrowserEnvironment.prototype.http = function (method, url, data, resolve, reject) {
        if (typeof XMLHttpRequest === "undefined") {
            return reject(new Error("Not running in browser"));
        }
        try {
            var request_1 = new XMLHttpRequest();
            request_1.open(method, url, true);
            request_1.setRequestHeader("Content-Type", "application/json");
            request_1.onerror = function () { return reject(new Error(request_1.statusText)); };
            request_1.onreadystatechange = function () {
                if (request_1.readyState === 4)
                    if (request_1.status === 200) {
                        resolve(JSON.parse(request_1.responseText));
                    }
                    else {
                        reject(new Error("Request failed with status " + request_1.status));
                    }
            };
            if (data !== undefined) {
                request_1.send(JSON.stringify(data));
            }
            else {
                request_1.send();
            }
        }
        catch (e) {
            return reject(e);
        }
    };
    BrowserEnvironment.prototype.getLocalStorage = function (key) {
        var value = localStorage[key];
        if (typeof value !== "string")
            return undefined;
        return value;
    };
    BrowserEnvironment.prototype.setLocalStorage = function (key, value) {
        localStorage[key] = value;
    };
    BrowserEnvironment.prototype.startHTMLExperiments = function () {
        html_1.startHTMLExperiments();
    };
    BrowserEnvironment.prototype.autocomplete = function (complete) {
        var _loop_1 = function (delay, reward) {
            setTimeout(function () { return complete(reward); }, delay * 1000);
        };
        for (var _i = 0, _a = [[10, 0.1], [60, 0.2]]; _i < _a.length; _i++) {
            var _b = _a[_i], delay = _b[0], reward = _b[1];
            _loop_1(delay, reward);
        }
    };
    return BrowserEnvironment;
}());
exports.BrowserEnvironment = BrowserEnvironment;
//# sourceMappingURL=BrowserEnvironment.js.map