import { Outcome } from "../common/ClientConfig";
import { Environment } from "./Environment";
export declare type Outcomes = {
    [experimentKey: string]: Outcome;
};
export declare class ExperimentOptions {
    readonly bestOption: string | undefined;
    readonly epsilon: number;
    constructor(bestOption?: string | undefined, epsilon?: number);
}
export declare type CompletionCallback = () => void;
export declare class Client {
    private readonly environment;
    private readonly appKey;
    private serialized;
    private readonly experimentOptions;
    private readonly experiments;
    private readonly defaultCompletions;
    private queuedCompletedExperiments;
    private queuedStartedExperiments;
    private preinitialized;
    constructor(environment: Environment, appKey: string, then: (c: Client) => void, outcomes?: Outcomes);
    log(...args: any[]): void;
    private error(...args);
    private serializeStateDebounced;
    private clientContext;
    private getClientContext();
    private startExperiment(theExperiment);
    private startExperimentsDebounced;
    completeExperiment(theExperiment: Experiment, then: CompletionCallback | undefined): void;
    private completeExperimentsDebounced;
    completeDefaults(score: number, then: CompletionCallback | undefined): void;
    private finishInit(outcomes);
    experiment(name: string, optionNames: string[]): Experiment;
    private storageKey(path);
    loadPick(name: string): string | undefined;
    savePick(name: string, pick: string): void;
}
export declare class Experiment {
    private readonly client;
    readonly name: string;
    readonly optionNames: string[];
    readonly options: ExperimentOptions;
    readonly key: string;
    readonly pick: string;
    readonly pickedBest: boolean;
    payoff?: number;
    constructor(client: Client, name: string, optionNames: string[], options: ExperimentOptions);
    complete(payoff: number | undefined, then: CompletionCallback | undefined): void;
}
