"use strict";
exports.__esModule = true;
var _1 = require(".");
var util_1 = require("./util");
function optionNodeLabelOrText(node, allowTextContent) {
    if (allowTextContent === void 0) { allowTextContent = "allow textContent"; }
    return (node.getAttribute("data-option") ||
        node.getAttribute("option") ||
        (allowTextContent ? node.textContent : undefined) ||
        util_1.hash(node.outerHTML).toString());
}
exports.optionNodeLabelOrText = optionNodeLabelOrText;
function optionsForNodeChildren(children) {
    var options = util_1.unique(util_1.map(children, function (c) { return optionNodeLabelOrText(c); }));
    if (options.length !== children.length) {
        options = util_1.map(children, function (c) { return optionNodeLabelOrText(c, "no textContent"); });
    }
    return options;
}
exports.optionsForNodeChildren = optionsForNodeChildren;
function getTagExperiments() {
    var experiments = {};
    var customTagNodes = document.getElementsByTagName("autotune");
    util_1.each(customTagNodes, function (node) {
        var name = node.getAttribute("data-experiment") ||
            node.getAttribute("experiment") ||
            util_1.hash(node.innerHTML).toString();
        var data = { node: node, options: optionsForNodeChildren(node.children) };
        var list = experiments[name] || [];
        list.push(data);
        experiments[name] = list;
    });
    return experiments;
}
function getAttributeExperiments() {
    var experiments = {};
    var attributedNodes = document.querySelectorAll("[data-experiment]");
    util_1.each(attributedNodes, function (node) {
        var name = node.getAttribute("data-experiment");
        var option = node.getAttribute("data-option");
        if (name === null || option === null)
            return;
        var data = experiments[name];
        if (data === undefined) {
            data = experiments[name] = { options: [], nodes: [] };
        }
        if (data.options.indexOf(option) === -1) {
            data.options.push(option);
        }
        data.nodes.push(node);
    });
    return experiments;
}
function getClassAttributeExperiments() {
    var experiments = {};
    var attributedNodes = document.querySelectorAll("[autotune-class],[data-autotune-class]");
    util_1.each(attributedNodes, function (node) {
        var classesRaw = node.getAttribute("autotune-class") || node.getAttribute("data-autotune-class") || "";
        var classes = classesRaw.split(" ");
        var experimentName = node.getAttribute("autotune-experiment") ||
            node.getAttribute("data-autotune-experiment") ||
            util_1.hash(node.innerHTML) + "-class";
        experiments[experimentName] = { options: classes, node: node };
    });
    return experiments;
}
function startHTMLExperiments() {
    function start() {
        gatherAndStartDOMExperiments();
        setupHTMLCompletions();
    }
    if (document.readyState === "complete") {
        start();
    }
    else {
        document.addEventListener("DOMContentLoaded", function () {
            start();
        });
    }
}
exports.startHTMLExperiments = startHTMLExperiments;
function setupHTMLCompletions() {
    var clickables = document.querySelectorAll("a[autotune],a[data-autotune],button[autotune],button[data-autotune]");
    util_1.each(clickables, function (clickable) {
        var onclick = clickable.onclick;
        clickable.onclick = function (event) {
            event.preventDefault();
            _1.complete(function () {
                if (typeof onclick === "function") {
                    onclick.bind(clickable)(event);
                }
                else if (clickable instanceof HTMLAnchorElement) {
                    window.location.href = clickable.href;
                }
            });
        };
    });
}
function gatherAndStartDOMExperiments() {
    var attributeExperiments = getAttributeExperiments();
    var tagExperiments = getTagExperiments();
    Object.getOwnPropertyNames(attributeExperiments).forEach(function (name) {
        var _a = attributeExperiments[name], options = _a.options, nodes = _a.nodes;
        var choice = _1.oneOf(name, options);
        nodes.forEach(function (node) {
            if (node.getAttribute("data-option") !== choice) {
                node.remove();
            }
        });
    });
    Object.getOwnPropertyNames(tagExperiments).forEach(function (name) {
        var options = {};
        tagExperiments[name].forEach(function (experiment) {
            experiment.options.forEach(function (o) { return (options[o] = null); });
        });
        var choice = _1.oneOf(name, Object.getOwnPropertyNames(options));
        tagExperiments[name].forEach(function (experiment) {
            util_1.map(experiment.node.children, function (x) { return x; })
                .forEach(function (child) {
                if (optionNodeLabelOrText(child) !== choice) {
                    child.remove();
                }
            });
        });
    });
    var classExperiments = getClassAttributeExperiments();
    Object.getOwnPropertyNames(classExperiments).forEach(function (name) {
        var experiment = classExperiments[name];
        var pick = _1.oneOf(name, experiment.options);
        experiment.node.classList.add(pick);
    });
}
//# sourceMappingURL=html.js.map