"use strict";
exports.__esModule = true;
var html_1 = require("./html");
function element(html) {
    var template = document.createElement("template");
    template.innerHTML = html.trim();
    return template.content.firstElementChild;
}
describe("optionNodeLabelOrText", function () {
    var expectLabel = function (html) { return expect(html_1.optionNodeLabelOrText(element(html), "allow textContent")); };
    it("data-option", function () { return expectLabel("<div data-option=\"x\"></div>").toBe("x"); });
    it("option", function () { return expectLabel("<div option=\"x\"></div>").toBe("x"); });
    it("textContent", function () { return expectLabel("<div>x</div>").toBe("x"); });
    it("prefers data-option to textContent", function () { return expectLabel("<div option=\"x\">y</div>").toBe("x"); });
    it("prefers data-option to option", function () { return expectLabel("<div data-option=\"x\" option=\"y\">z</div>").toBe("x"); });
});
describe("optionsForNodeChildren", function () {
    var expectOptions = function (html) { return expect(html_1.optionsForNodeChildren(element(html).children)); };
    it("basic case", function () {
        return expectOptions("<autotune>\n        <div option=\"x\">Hello</div>\n        <div option=\"y\">World</div>\n    </autotune>").toEqual(["x", "y"]);
    });
    it("can mix labeled options and text content", function () {
        return expectOptions("<autotune>\n        <div option=\"x\">a</div>\n        <div>b</div>\n    </autotune>").toEqual(["x", "b"]);
    });
    it("allows unique text content", function () {
        return expectOptions("<autotune>\n        <div>a</div>\n        <div>b</div>\n    </autotune>").toEqual(["a", "b"]);
    });
});
//# sourceMappingURL=html.test.js.map