"use strict";
exports.__esModule = true;
var Client_1 = require("./Client");
var BrowserEnvironment_1 = require("./BrowserEnvironment");
var env = new BrowserEnvironment_1.BrowserEnvironment();
var client;
function initialize(appKey, then, outcomes) {
    if (client !== undefined) {
        env.error("autotune initialized more than once");
        return;
    }
    client = new Client_1.Client(env, appKey, then, outcomes);
}
exports.initialize = initialize;
function flipCoin(experimentName) {
    if (client === undefined) {
        env.error("autotune must be initialized before calling flipCoin");
        return true;
    }
    var ex = client.experiment(experimentName, ["true", "false"]);
    return ex.pick === "true";
}
exports.flipCoin = flipCoin;
function oneOf(experimentName, options) {
    var optionsIsArray = Object.prototype.toString.call(options) === "[object Array]";
    var optionNames;
    if (optionsIsArray) {
        optionNames = options;
    }
    else {
        optionNames = Object.getOwnPropertyNames(options);
    }
    var pick;
    if (client === undefined) {
        env.error("autotune must be initialized before calling oneOf");
        pick = optionNames[0];
    }
    else {
        var ex = client.experiment(experimentName, optionNames);
        pick = ex.pick;
    }
    if (optionsIsArray) {
        return pick;
    }
    else {
        return options[pick];
    }
}
exports.oneOf = oneOf;
function complete(scoreOrThen, maybeThen) {
    if (client === undefined) {
        env.error("autotune must be initialized before calling complete");
        return;
    }
    var score;
    if (typeof scoreOrThen === "number") {
        score = scoreOrThen;
    }
    else {
        score = 1;
    }
    var then;
    if (typeof scoreOrThen === "function") {
        then = scoreOrThen;
    }
    else {
        then = maybeThen;
    }
    client.completeDefaults(score, then);
}
exports.complete = complete;
if (typeof window !== "undefined" && typeof window.autotuneConfig !== "undefined") {
    var config = window.autotuneConfig;
    initialize(config.appKey, function () {
        return;
    }, config.outcomes);
}
//# sourceMappingURL=index.js.map