"use strict";
exports.__esModule = true;
var Convert;
(function (Convert) {
    function toSerializedState(json) {
        return cast(JSON.parse(json), r("SerializedState"));
    }
    Convert.toSerializedState = toSerializedState;
    function serializedStateToJson(value) {
        return JSON.stringify(value, null, 2);
    }
    Convert.serializedStateToJson = serializedStateToJson;
    function cast(obj, typ) {
        if (!isValid(typ, obj)) {
            throw Error("Invalid value");
        }
        return obj;
    }
    function isValid(typ, val) {
        if (typ === "any") {
            return true;
        }
        if (typ === null) {
            return val === null;
        }
        if (typ === false) {
            return false;
        }
        while (typeof typ === "object" && typ.ref !== undefined) {
            typ = typeMap[typ.ref];
        }
        if (Array.isArray(typ)) {
            return isValidEnum(typ, val);
        }
        if (typeof typ === "object") {
            return typ.hasOwnProperty("unionMembers") ? isValidUnion(typ.unionMembers, val)
                : typ.hasOwnProperty("arrayItems") ? isValidArray(typ.arrayItems, val)
                    : typ.hasOwnProperty("props") ? isValidObject(typ.props, typ.additional, val)
                        : false;
        }
        return isValidPrimitive(typ, val);
    }
    function isValidPrimitive(typ, val) {
        return typeof typ === typeof val;
    }
    function isValidUnion(typs, val) {
        return typs.some(function (typ) { return isValid(typ, val); });
    }
    function isValidEnum(cases, val) {
        return cases.indexOf(val) !== -1;
    }
    function isValidArray(typ, val) {
        return Array.isArray(val) && val.every(function (element) {
            return isValid(typ, element);
        });
    }
    function isValidObject(props, additional, val) {
        if (val === null || typeof val !== "object" || Array.isArray(val)) {
            return false;
        }
        return Object.getOwnPropertyNames(val).every(function (key) {
            var prop = val[key];
            if (Object.prototype.hasOwnProperty.call(props, key)) {
                return isValid(props[key], prop);
            }
            return isValid(additional, prop);
        });
    }
    function a(typ) {
        return { arrayItems: typ };
    }
    function u() {
        var typs = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            typs[_i] = arguments[_i];
        }
        return { unionMembers: typs };
    }
    function o(props, additional) {
        return { props: props, additional: additional };
    }
    function m(additional) {
        return { props: {}, additional: additional };
    }
    function r(name) {
        return { ref: name };
    }
    var typeMap = {
        "SerializedState": o({
            experimentPicks: m(""),
            lastInitialized: 0
        }, "any")
    };
})(Convert = exports.Convert || (exports.Convert = {}));
//# sourceMappingURL=models.js.map